@@ -5,7 +5,8 @@ set -eu
 : ${BST:=bst}
 export BST
 
-: ${REPO_ELEMENT:=vm/repo.bst}
+: ${REPO_ELEMENT:=vm/repo-devel.bst}
+: ${OSTREE_LAYER:=git}
 
 ref="$(${BST} show --format "%{vars}" --deps none "${REPO_ELEMENT}" | sed '/ostree-branch: /{;s///;q;};d')"
 
@@ -29,11 +30,12 @@ EOF
     mv ostree-gpg.tmp ostree-gpg
 fi
 
-utils/update-repo.sh \
+script_dir=$(dirname $0)
+$script_dir/update-repo.sh \
     --gpg-homedir=ostree-gpg \
     --gpg-sign="$(cat ostree-gpg/default-id)" \
     --collection-id=org.gnome.GnomeOS \
-    --target-ref="${ref%/*}/devel" \
+    --target-ref="${ref%-*}-${OSTREE_LAYER}" \
     ostree-repo "${REPO_ELEMENT}" \
     "${ref}"
 
